@@ -120,7 +120,7 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
     </message>
     <message>
         <source>%1 (%2)</source>
-        <extracomment>&lt;language&gt; (&lt;country&gt;)</extracomment>
+        <extracomment>&lt;language&gt; (&lt;territory&gt;)</extracomment>
         <translation>%1 (%2)</translation>
     </message>
     <message>
@@ -950,10 +950,6 @@ Alle Dateien (*)</translation>
         <source>Qt Linguist is a tool for adding translations to Qt applications.</source>
         <translation>Qt Linguist ist ein Werkzeug zum Hinzufügen von Übersetzungen zu Qt-Anwendungen</translation>
     </message>
-    <message>
-        <source>Copyright (C) %1 The Qt Company Ltd.</source>
-        <translation>Copyright (C) %1 The Qt Company Ltd.</translation>
-    </message>
     <message>
         <source>Do you want to save the modified files?</source>
         <translation>Möchten Sie die geänderten Dateien speichern?</translation>
@@ -1329,6 +1325,14 @@ Alle Dateien (*)</translation>
         <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
         <translation>Dieser Bereich zeigt eventuelle Kommentare und den Kontext, in dem der Text auftritt.</translation>
     </message>
+    <message>
+        <source>NCR mode</source>
+        <translation>NCR-Modus</translation>
+    </message>
+    <message>
+        <source>Toggles Numeric Character Reference Mode for displaying the source text and the translations.</source>
+        <translation>Schaltet den Modus für numerische Zeichen zur Anzeige von Quelltext und Übersetzung um.</translation>
+    </message>
     <message>
         <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
         <translation>Hier können Sie Hinweise für den eigenen Gebrauch eintragen. Diese haben keinen Einflusse auf die Übersetzung.</translation>
@@ -1382,14 +1386,6 @@ Zeile: %2</translation>
         </translation>
     </message>
 </context>
-<context>
-    <name>MsgEdit</name>
-    <message>
-        <source></source>
-        <comment>This is the right panel of the main window.</comment>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>PhraseBook</name>
     <message>
@@ -1687,8 +1683,8 @@ Zeile: %2</translation>
         <translation>%1 (%2)</translation>
     </message>
     <message>
-        <source>Any Country</source>
-        <translation>Land</translation>
+        <source>Any Territory</source>
+        <translation>Beliebiges Territorium</translation>
     </message>
     <message>
         <source>Settings for &apos;%1&apos; - Qt Linguist</source>
